****************************************
Unleash Python Client Documentation
****************************************

Documentation for Unleash's Python client.  See the sidebar for more topics!

.. Hidden TOCs

.. toctree::
    :caption: Basic Usage
    :maxdepth: 2
    :hidden:

    installation
    usage

.. toctree::
    :caption: Advanced
    :maxdepth: 2
    :hidden:

    customstrategies
    customcache
    development
    wsgi
    celery

.. toctree::
    :caption: API Documentation
    :maxdepth: 2
    :hidden:

    unleashclient
    strategy
    filecache
    basecache

.. toctree::
    :caption: Changelog
    :maxdepth: 2
    :hidden:

    changelog
